==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkDSPFilterGroup.java <==
// java wrapper for vtkDSPFilterGroup object
//

package vtk;
import vtk.*;

public class vtkDSPFilterGroup extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddFilter_2(vtkDSPFilterDefinition id0);
  public void AddFilter(vtkDSPFilterDefinition id0)
    { AddFilter_2(id0); }

  private native void RemoveFilter_3(String id0);
  public void RemoveFilter(String id0)
    { RemoveFilter_3(id0); }

  private native boolean IsThisInputVariableInstanceNeeded_4(String id0,int id1,int id2);
  public boolean IsThisInputVariableInstanceNeeded(String id0,int id1,int id2)
    { return IsThisInputVariableInstanceNeeded_4(id0,id1,id2); }

  private native boolean IsThisInputVariableInstanceCached_5(String id0,int id1);
  public boolean IsThisInputVariableInstanceCached(String id0,int id1)
    { return IsThisInputVariableInstanceCached_5(id0,id1); }

  private native void AddInputVariableInstance_6(String id0,int id1,vtkFloatArray id2);
  public void AddInputVariableInstance(String id0,int id1,vtkFloatArray id2)
    { AddInputVariableInstance_6(id0,id1,id2); }

  private native long GetCachedInput_7(int id0,int id1);
  public vtkFloatArray GetCachedInput(int id0,int id1) {
    long temp = GetCachedInput_7(id0,id1);

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCachedOutput_8(int id0,int id1);
  public vtkFloatArray GetCachedOutput(int id0,int id1) {
    long temp = GetCachedOutput_8(id0,id1);

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetInputVariableName_9(int id0);
  public String GetInputVariableName(int id0)
    { return GetInputVariableName_9(id0); }

  private native int GetNumFilters_10();
  public int GetNumFilters()
    { return GetNumFilters_10(); }

  private native void Copy_11(vtkDSPFilterGroup id0);
  public void Copy(vtkDSPFilterGroup id0)
    { Copy_11(id0); }

  private native long GetFilter_12(int id0);
  public vtkDSPFilterDefinition GetFilter(int id0) {
    long temp = GetFilter_12(id0);

    if (temp == 0) return null;
    return (vtkDSPFilterDefinition)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkDSPFilterGroup() { super(); }

  public vtkDSPFilterGroup(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkDSPFilterGroup.java <==
// java wrapper for vtkDSPFilterGroup object
//

package vtk;
import vtk.*;

public class vtkDSPFilterGroup extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddFilter_2(vtkDSPFilterDefinition id0);
  public void AddFilter(vtkDSPFilterDefinition id0)
    { AddFilter_2(id0); }

  private native void RemoveFilter_3(String id0);
  public void RemoveFilter(String id0)
    { RemoveFilter_3(id0); }

  private native boolean IsThisInputVariableInstanceNeeded_4(String id0,int id1,int id2);
  public boolean IsThisInputVariableInstanceNeeded(String id0,int id1,int id2)
    { return IsThisInputVariableInstanceNeeded_4(id0,id1,id2); }

  private native boolean IsThisInputVariableInstanceCached_5(String id0,int id1);
  public boolean IsThisInputVariableInstanceCached(String id0,int id1)
    { return IsThisInputVariableInstanceCached_5(id0,id1); }

  private native void AddInputVariableInstance_6(String id0,int id1,vtkFloatArray id2);
  public void AddInputVariableInstance(String id0,int id1,vtkFloatArray id2)
    { AddInputVariableInstance_6(id0,id1,id2); }

  private native long GetCachedInput_7(int id0,int id1);
  public vtkFloatArray GetCachedInput(int id0,int id1) {
    long temp = GetCachedInput_7(id0,id1);

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCachedOutput_8(int id0,int id1);
  public vtkFloatArray GetCachedOutput(int id0,int id1) {
    long temp = GetCachedOutput_8(id0,id1);

    if (temp == 0) return null;
    return (vtkFloatArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetInputVariableName_9(int id0);
  public String GetInputVariableName(int id0)
    { return GetInputVariableName_9(id0); }

  private native int GetNumFilters_10();
  public int GetNumFilters()
    { return GetNumFilters_10(); }

  private native void Copy_11(vtkDSPFilterGroup id0);
  public void Copy(vtkDSPFilterGroup id0)
    { Copy_11(id0); }

  private native long GetFilter_12(int id0);
  public vtkDSPFilterDefinition GetFilter(int id0) {
    long temp = GetFilter_12(id0);

    if (temp == 0) return null;
    return (vtkDSPFilterDefinition)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkDSPFilterGroup() { super(); }

  public vtkDSPFilterGroup(long id) { super(id); }
  public native long   VTKInit();

}
